<?php

namespace Drupal\entity_reference_edit_link\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldWidget\EntityReferenceAutocompleteWidget;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class to alter original entity reference autocomplete tags widget.
 */
class EntityReferenceEditLinkAutocompleteWidget extends EntityReferenceAutocompleteWidget {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $referencedEntities = $items->referencedEntities();
    $referencedEntity = $referencedEntities[$delta] ?? NULL;

    if (!$referencedEntity) {
      return parent::formElement($items, $delta, $element, $form, $form_state);
    }

    $element += [
      '#attached' => [
        'library' => ['entity_reference_edit_link/reference.field'],
      ],
    ];

    $link = [
      '#type' => 'container',
      'link' => [
        '#type' => 'link',
        '#title' => $this->t('Edit'),
        '#url' => $referencedEntity->toUrl('edit-form'),
        '#attributes' => [
          'class' => ['button reference-edit-link'],
          'target' => '_blank',
        ],
      ],
    ];

    return parent::formElement($items, $delta, $element, $form, $form_state) + ['_link' => $link];
  }

}
